==> modx-2.0.5-pl-ja.zip: modx-2.0.5-pl-ja/core/lexicon/en/permissions.inc.php <==
<?php
/**
 * Permissions English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['perm.about_desc'] = 'The About page.';
$_lang['perm.access_permissions_desc'] = 'Any Access Permission-related pages and actions.';
$_lang['perm.actions_desc'] = 'The Actions page.';
$_lang['perm.add_children_desc'] = 'To add any Resources as children of the specified Resource or Elements to a Category.';
$_lang['perm.change_password_desc'] = 'User can change their user password.';
$_lang['perm.change_profile_desc'] = 'User can change their profile.';
$_lang['perm.charsets_desc'] = 'To view a list of charsets.';
$_lang['perm.class_map_desc'] = 'To view a list of classes in the Class Map.';
$_lang['perm.components_desc'] = 'To view the Components menu.';
$_lang['perm.content_types_desc'] = 'The Content Types page.';
$_lang['perm.copy_desc'] = 'The ability to copy an object.';
$_lang['perm.countries_desc'] = 'To view a list of countries.';
$_lang['perm.create_desc'] = 'Basic "create" access on new objects.';
$_lang['perm.credits_desc'] = 'View the Credits page.';
$_lang['perm.customize_forms_desc'] = 'View and manage the Form Customization page.';
$_lang['perm.database_desc'] = 'The System Info page.';
$_lang['perm.database_truncate_desc'] = 'The ability to truncate a database table.';
$_lang['perm.delete_desc'] = 'Basic "delete" access on objects.';
$_lang['perm.delete_category_desc'] = 'To delete or remove any Categories.';
$_lang['perm.delete_chunk_desc'] = 'To delete or remove any Chunks.';
$_lang['perm.delete_context_desc'] = 'To delete or remove any Contexts.';
$_lang['perm.delete_document_desc'] = 'To delete or remove any Resource.';
$_lang['perm.delete_eventlog_desc'] = 'To empty the Event Log.';
$_lang['perm.delete_plugin_desc'] = 'To delete or remove any Plugins.';
$_lang['perm.delete_propertyset_desc'] = 'To delete or remove any Property Sets.';
$_lang['perm.delete_role_desc'] = 'To delete or remove any Roles.';
$_lang['perm.delete_snippet_desc'] = 'To delete or remove any Snippets.';
$_lang['perm.delete_template_desc'] = 'To delete or remove any Templates.';
$_lang['perm.delete_tv_desc'] = 'To delete or remove any Template Variables.';
$_lang['perm.delete_user_desc'] = 'To delete or remove any Users.';
$_lang['perm.directory_chmod_desc'] = 'To chmod a physical directory.';
$_lang['perm.directory_create_desc'] = 'To create a physical directory.';
$_lang['perm.directory_list_desc'] = 'To list subdirectories for a physical directory.';
$_lang['perm.directory_remove_desc'] = 'To remove a physical directory.';
$_lang['perm.directory_update_desc'] = 'To rename a physical directory.';
$_lang['perm.edit_category_desc'] = 'To edit any Categories.';
$_lang['perm.edit_chunk_desc'] = 'To edit any Chunks.';
$_lang['perm.edit_context_desc'] = 'To edit any Contexts.';
$_lang['perm.edit_document_desc'] = 'To edit any Resources.';
$_lang['perm.edit_locked_desc'] = 'Allows a user to override a lock and edit a locked Resource.';
$_lang['perm.edit_plugin_desc'] = 'To edit any Plugins.';
$_lang['perm.edit_propertyset_desc'] = 'To edit any Property Sets.';
$_lang['perm.edit_role_desc'] = 'To edit any Roles.';
$_lang['perm.edit_snippet_desc'] = 'To edit any Snippets.';
$_lang['perm.edit_template_desc'] = 'To edit any Templates.';
$_lang['perm.edit_tv_desc'] = 'To edit any Template Variables.';
$_lang['perm.edit_user_desc'] = 'To edit any User.';
$_lang['perm.element_tree_desc'] = 'The ability to view the Elements Tree on the left nav.';
$_lang['perm.empty_cache_desc'] = 'To empty the site cache.';
$_lang['perm.error_log_erase_desc'] = 'To erase the error log.';
$_lang['perm.error_log_view_desc'] = 'To view the error log.';
$_lang['perm.export_static_desc'] = 'To export the site to static HTML.';
$_lang['perm.file_list_desc'] = 'To list files within a given physical directory.';
$_lang['perm.file_manager_desc'] = 'To use the file manager utility.';
$_lang['perm.file_remove_desc'] = 'To remove physical files.';
$_lang['perm.file_tree_desc'] = 'To view the Files Tree on the left nav.';
$_lang['perm.file_update_desc'] = 'To update the content of physical files.';
$_lang['perm.file_upload_desc'] = 'To upload files to a directory.';
$_lang['perm.file_view_desc'] = 'To view the contents of a file.';
$_lang['perm.flush_sessions_desc'] = 'Can flush Sessions across the site.';
$_lang['perm.frames_desc'] = 'To use the MODx Manager UI at all.';
$_lang['perm.help_desc'] = 'To view the Help page.';
$_lang['perm.home_desc'] = 'To view the Welcome page.';
$_lang['perm.import_static_desc'] = 'To view or use the Import pages.';
$_lang['perm.languages_desc'] = 'To edit or view Lexicon Languages.';
$_lang['perm.lexicons_desc'] = 'To edit or view Lexicons and Internationalization.';
$_lang['perm.list_desc'] = 'Basic permission to "list" any object. List means to get a collection of objects.';
$_lang['perm.load_desc'] = 'Basic permission to "load" any object, or be able to return it as an instance at all.';
$_lang['perm.logout_desc'] = 'To be able to logout as a user.';
$_lang['perm.logs_desc'] = 'To view the logs, such as error and manager logs.';
$_lang['perm.menus_desc'] = 'To edit or save any top Menu items.';
$_lang['perm.messages_desc'] = 'To send or view any personal Messages.';
$_lang['perm.move_desc'] = 'Basic "move" access on any object.';
$_lang['perm.namespaces_desc'] = 'To edit or view Namespaces.';
$_lang['perm.new_category_desc'] = 'To create a new Category.';
$_lang['perm.new_chunk_desc'] = 'To create a new Chunk.';
$_lang['perm.new_context_desc'] = 'To create a new Context.';
$_lang['perm.new_document_desc'] = 'To create a new Resource.';
$_lang['perm.new_document_in_root_desc'] = 'To be able to create a Resource at the root level.';
$_lang['perm.new_plugin_desc'] = 'To create a new Plugin.';
$_lang['perm.new_propertyset_desc'] = 'To create a new Property Set.';
$_lang['perm.new_role_desc'] = 'To create a new Role.';
$_lang['perm.new_snippet_desc'] = 'To create a new Snippet.';
$_lang['perm.new_template_desc'] = 'To create a new Template.';
$_lang['perm.new_tv_desc'] = 'To create a new Template Variable.';
$_lang['perm.new_user_desc'] = 'To create a new User.';
$_lang['perm.packages_desc'] = 'To use any Transport Packages in the Package Management system.';
$_lang['perm.property_sets_desc'] = 'To view and edit Properties and Property Sets.';
$_lang['perm.providers_desc'] = 'To view and edit Providers across the site.';
$_lang['perm.publish_desc'] = 'Basic "publish" access on any object.';
$_lang['perm.publish_document_desc'] = 'To publish or unpublish any Resource.';
$_lang['perm.purge_deleted_desc'] = 'To empty the Recycle Bin.';
$_lang['perm.remove_desc'] = 'Basic permission to remove any object.';
$_lang['perm.remove_locks_desc'] = 'To remove all existing Locks throughout the site.';
$_lang['perm.resource_tree_desc'] = 'To view the Resource Tree in the left nav.';
$_lang['perm.save_desc'] = 'Basic save permission for any object.';
$_lang['perm.save_category_desc'] = 'To save any Categories.';
$_lang['perm.save_chunk_desc'] = 'To save any Chunks.';
$_lang['perm.save_context_desc'] = 'To save any Contexts.';
$_lang['perm.save_document_desc'] = 'To save any Resources.';
$_lang['perm.save_plugin_desc'] = 'To save any Plugins.';
$_lang['perm.save_propertyset_desc'] = 'To save any Property Sets.';
$_lang['perm.save_role_desc'] = 'To save any Roles.';
$_lang['perm.save_snippet_desc'] = 'To save any Snippets.';
$_lang['perm.save_template_desc'] = 'To save any Templates.';
$_lang['perm.save_tv_desc'] = 'To save any Template Variables.';
$_lang['perm.save_user_desc'] = 'To save any Users.';
$_lang['perm.search_desc'] = 'To use the Search page.';
$_lang['perm.settings_desc'] = 'To view and edit any System Settings.';
$_lang['perm.steal_lock_desc'] = 'To "steal", or remove, a lock from a Resource.';
$_lang['perm.steal_locks_desc'] = 'To "steal" locks, overriding a current lock on a Resource.';
$_lang['perm.undelete_desc'] = 'Basic permission to "undelete" any object.';
$_lang['perm.undelete_document_desc'] = 'To undelete any Resource.';
$_lang['perm.unlock_element_properties_desc'] = 'To be able to edit the default properties for any Element.';
$_lang['perm.unpublish_desc'] = 'To unpublish any Resource.';
$_lang['perm.unpublish_document_desc'] = 'To unpublish any Resources.';
$_lang['perm.view_desc'] = 'Basic permission to "view" any object.';
$_lang['perm.view_category_desc'] = 'To view any Categories.';
$_lang['perm.view_chunk_desc'] = 'To view any Chunks.';
$_lang['perm.view_context_desc'] = 'To view any Contexts.';
$_lang['perm.view_document_desc'] = 'To view any Resources.';
$_lang['perm.view_element_desc'] = 'To get a list of Elements or Element classes.';
$_lang['perm.view_eventlog_desc'] = 'To view the Event Log.';
$_lang['perm.view_offline_desc'] = 'To be able to view the site when it is in offline status.';
$_lang['perm.view_plugin_desc'] = 'To view any Plugins.';
$_lang['perm.view_propertyset_desc'] = 'To view any Property Sets.';
$_lang['perm.view_role_desc'] = 'To view any Roles.';
$_lang['perm.view_snippet_desc'] = 'To view any Snippets.';
$_lang['perm.view_sysinfo_desc'] = 'To view the system info page.';
$_lang['perm.view_template_desc'] = 'To view any Templates.';
$_lang['perm.view_tv_desc'] = 'To view any Template Variables.';
$_lang['perm.view_unpublished_desc'] = 'To view any unpublished Resources.';
$_lang['perm.view_user_desc'] = 'To view any User.';
$_lang['perm.workspaces_desc'] = 'To use Package Management.';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/en/permissions.inc.php <==
<?php
/**
 * Permissions English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['perm.about_desc'] = 'The About page.';
$_lang['perm.access_permissions_desc'] = 'Any Access Permission-related pages and actions.';
$_lang['perm.actions_desc'] = 'The Actions page.';
$_lang['perm.add_children_desc'] = 'To add any Resources as children of the specified Resource or Elements to a Category.';
$_lang['perm.change_password_desc'] = 'User can change their user password.';
$_lang['perm.change_profile_desc'] = 'User can change their profile.';
$_lang['perm.charsets_desc'] = 'To view a list of charsets.';
$_lang['perm.class_map_desc'] = 'To view a list of classes in the Class Map.';
$_lang['perm.components_desc'] = 'To view the Extras menu.';
$_lang['perm.content_types_desc'] = 'The Content Types page.';
$_lang['perm.copy_desc'] = 'The ability to copy an object.';
$_lang['perm.countries_desc'] = 'To view a list of countries.';
$_lang['perm.create_desc'] = 'Basic "create" access on new objects.';
$_lang['perm.credits_desc'] = 'View the Credits page.';
$_lang['perm.customize_forms_desc'] = 'View and manage the Form Customization page.';
$_lang['perm.dashboards_desc'] = 'View and manage Custom Dashboards.';
$_lang['perm.database_desc'] = 'The System Info page.';
$_lang['perm.database_truncate_desc'] = 'The ability to truncate a database table.';
$_lang['perm.delete_desc'] = 'Basic "delete" access on objects.';
$_lang['perm.delete_category_desc'] = 'To delete or remove any Categories.';
$_lang['perm.delete_chunk_desc'] = 'To delete or remove any Chunks.';
$_lang['perm.delete_context_desc'] = 'To delete or remove any Contexts.';
$_lang['perm.delete_document_desc'] = 'To delete or remove any Resource.';
$_lang['perm.delete_eventlog_desc'] = 'To empty the Event Log.';
$_lang['perm.delete_plugin_desc'] = 'To delete or remove any Plugins.';
$_lang['perm.delete_propertyset_desc'] = 'To delete or remove any Property Sets.';
$_lang['perm.delete_role_desc'] = 'To delete or remove any Roles.';
$_lang['perm.delete_snippet_desc'] = 'To delete or remove any Snippets.';
$_lang['perm.delete_template_desc'] = 'To delete or remove any Templates.';
$_lang['perm.delete_tv_desc'] = 'To delete or remove any Template Variables.';
$_lang['perm.delete_user_desc'] = 'To delete or remove any Users.';
$_lang['perm.directory_chmod_desc'] = 'To chmod a physical directory.';
$_lang['perm.directory_create_desc'] = 'To create a physical directory.';
$_lang['perm.directory_list_desc'] = 'To list subdirectories for a physical directory.';
$_lang['perm.directory_remove_desc'] = 'To remove a physical directory.';
$_lang['perm.directory_update_desc'] = 'To rename a physical directory.';
$_lang['perm.edit_category_desc'] = 'To edit any Categories.';
$_lang['perm.edit_chunk_desc'] = 'To edit any Chunks.';
$_lang['perm.edit_context_desc'] = 'To edit any Contexts.';
$_lang['perm.edit_document_desc'] = 'To edit any Resources.';
$_lang['perm.edit_locked_desc'] = 'Allows a user to override a lock and edit a locked Resource.';
$_lang['perm.edit_plugin_desc'] = 'To edit any Plugins.';
$_lang['perm.edit_propertyset_desc'] = 'To edit any Property Sets.';
$_lang['perm.edit_role_desc'] = 'To edit any Roles.';
$_lang['perm.edit_snippet_desc'] = 'To edit any Snippets.';
$_lang['perm.edit_template_desc'] = 'To edit any Templates.';
$_lang['perm.edit_tv_desc'] = 'To edit any Template Variables.';
$_lang['perm.edit_user_desc'] = 'To edit any User.';
$_lang['perm.element_tree_desc'] = 'The ability to view the Elements Tree on the left nav.';
$_lang['perm.empty_cache_desc'] = 'To empty the site cache.';
$_lang['perm.error_log_erase_desc'] = 'To erase the error log.';
$_lang['perm.error_log_view_desc'] = 'To view the error log.';
$_lang['perm.export_static_desc'] = 'To export the site to static HTML.';
$_lang['perm.file_create_desc'] = 'To create a file.';
$_lang['perm.file_list_desc'] = 'To list files within a given physical directory.';
$_lang['perm.file_manager_desc'] = 'To use the file manager utility.';
$_lang['perm.file_remove_desc'] = 'To remove physical files.';
$_lang['perm.file_tree_desc'] = 'To view the Files Tree on the left nav.';
$_lang['perm.file_update_desc'] = 'To update the content of physical files.';
$_lang['perm.file_upload_desc'] = 'To upload files to a directory.';
$_lang['perm.file_view_desc'] = 'To view the contents of a file.';
$_lang['perm.flush_sessions_desc'] = 'Can flush Sessions across the site.';
$_lang['perm.frames_desc'] = 'To use the MODX Manager UI at all.';
$_lang['perm.help_desc'] = 'To view the Help page.';
$_lang['perm.home_desc'] = 'To view the Welcome page.';
$_lang['perm.import_static_desc'] = 'To view or use the Import pages.';
$_lang['perm.languages_desc'] = 'To edit or view Lexicon Languages.';
$_lang['perm.lexicons_desc'] = 'To edit or view Lexicons and Internationalization.';
$_lang['perm.list_desc'] = 'Basic permission to "list" any object. List means to get a collection of objects.';
$_lang['perm.load_desc'] = 'Basic permission to "load" any object, or be able to return it as an instance at all.';
$_lang['perm.logout_desc'] = 'To be able to logout as a user.';
$_lang['perm.logs_desc'] = 'To view the logs, such as error and manager logs.';
$_lang['perm.menu_reports_desc'] = 'Show the top menu item "Reports".';
$_lang['perm.menu_security_desc'] = 'Show the top menu item "Security".';
$_lang['perm.menu_site_desc'] = 'Show the top menu item "Site".';
$_lang['perm.menu_support_desc'] = 'Show the top menu item "Support".';
$_lang['perm.menu_system_desc'] = 'Show the top menu item "System".';
$_lang['perm.menu_tools_desc'] = 'Show the top menu item "Tools".';
$_lang['perm.menu_user_desc'] = 'Show the top menu item "User".';
$_lang['perm.menus_desc'] = 'To edit or save any top Menu items.';
$_lang['perm.messages_desc'] = 'To send or view any personal Messages.';
$_lang['perm.move_desc'] = 'Basic "move" access on any object.';
$_lang['perm.namespaces_desc'] = 'To edit or view Namespaces.';
$_lang['perm.new_category_desc'] = 'To create a new Category.';
$_lang['perm.new_chunk_desc'] = 'To create a new Chunk.';
$_lang['perm.new_context_desc'] = 'To create a new Context.';
$_lang['perm.new_document_desc'] = 'To create a new Resource.';
$_lang['perm.new_document_in_root_desc'] = 'To be able to create a Resource at the root level.';
$_lang['perm.new_plugin_desc'] = 'To create a new Plugin.';
$_lang['perm.new_propertyset_desc'] = 'To create a new Property Set.';
$_lang['perm.new_role_desc'] = 'To create a new Role.';
$_lang['perm.new_snippet_desc'] = 'To create a new Snippet.';
$_lang['perm.new_static_resource_desc'] = 'To create a new Static Resource.';
$_lang['perm.new_symlink_desc'] = 'To create a new SymLink.';
$_lang['perm.new_template_desc'] = 'To create a new Template.';
$_lang['perm.new_tv_desc'] = 'To create a new Template Variable.';
$_lang['perm.new_user_desc'] = 'To create a new User.';
$_lang['perm.new_weblink_desc'] = 'To create a new WebLink.';
$_lang['perm.packages_desc'] = 'To use any Transport Packages in the Package Management system.';
$_lang['perm.policy_delete_desc'] = 'To delete an Access Policy.';
$_lang['perm.policy_edit_desc'] = 'To edit an Access Policy.';
$_lang['perm.policy_new_desc'] = 'To create a new Access Policy.';
$_lang['perm.policy_save_desc'] = 'To save an Access Policy.';
$_lang['perm.policy_view_desc'] = 'To view an Access Policy.';
$_lang['perm.policy_template_delete_desc'] = 'To delete an Access Policy Template.';
$_lang['perm.policy_template_edit_desc'] = 'To edit an Access Policy Template.';
$_lang['perm.policy_template_new_desc'] = 'To create a new Access Policy Template.';
$_lang['perm.policy_template_save_desc'] = 'To save an Access Policy Template.';
$_lang['perm.policy_template_view_desc'] = 'To view an Access Policy Template.';
$_lang['perm.property_sets_desc'] = 'To view and edit Properties and Property Sets.';
$_lang['perm.providers_desc'] = 'To view and edit Providers across the site.';
$_lang['perm.publish_desc'] = 'Basic "publish" access on any object.';
$_lang['perm.publish_document_desc'] = 'To publish or unpublish any Resource.';
$_lang['perm.purge_deleted_desc'] = 'To empty the Recycle Bin.';
$_lang['perm.remove_desc'] = 'Basic permission to remove any object.';
$_lang['perm.remove_locks_desc'] = 'To remove all existing Locks throughout the site.';
$_lang['perm.resourcegroup_delete_desc'] = 'To delete a Resource Group.';
$_lang['perm.resourcegroup_edit_desc'] = 'To edit a Resource Group.';
$_lang['perm.resourcegroup_resource_edit_desc'] = 'To edit Resources in a Resource Group.';
$_lang['perm.resourcegroup_resource_list_desc'] = 'To view or list Resources in a Resource Group.';
$_lang['perm.resourcegroup_new_desc'] = 'To create a new Resource Group.';
$_lang['perm.resourcegroup_save_desc'] = 'To save a Resource Group.';
$_lang['perm.resourcegroup_view_desc'] = 'To list Resource Groups.';
$_lang['perm.resource_duplicate_desc'] = 'To duplicate a Resource.';
$_lang['perm.resource_quick_create_desc'] = 'To be able to use Quick Create Resource in the left-hand tree.';
$_lang['perm.resource_quick_update_desc'] = 'To be able to use Quick Update Resource in the left-hand tree.';
$_lang['perm.resource_tree_desc'] = 'To view the Resource Tree in the left nav.';
$_lang['perm.save_desc'] = 'Basic save permission for any object.';
$_lang['perm.save_category_desc'] = 'To save any Categories.';
$_lang['perm.save_chunk_desc'] = 'To save any Chunks.';
$_lang['perm.save_context_desc'] = 'To save any Contexts.';
$_lang['perm.save_document_desc'] = 'To save any Resources.';
$_lang['perm.save_plugin_desc'] = 'To save any Plugins.';
$_lang['perm.save_propertyset_desc'] = 'To save any Property Sets.';
$_lang['perm.save_role_desc'] = 'To save any Roles.';
$_lang['perm.save_snippet_desc'] = 'To save any Snippets.';
$_lang['perm.save_template_desc'] = 'To save any Templates.';
$_lang['perm.save_tv_desc'] = 'To save any Template Variables.';
$_lang['perm.save_user_desc'] = 'To save any Users.';
$_lang['perm.search_desc'] = 'To use the Search page.';
$_lang['perm.settings_desc'] = 'To view and edit any System Settings.';
$_lang['perm.source_delete_desc'] = 'To delete a Media Source.';
$_lang['perm.source_edit_desc'] = 'To edit a Media Source.';
$_lang['perm.source_save_desc'] = 'To create or save a Media Source.';
$_lang['perm.source_view_desc'] = 'To view and list Media Sources.';
$_lang['perm.sources_desc'] = 'To manage Media Sources and Media Source Types.';
$_lang['perm.steal_lock_desc'] = 'To "steal", or remove, a lock from a Resource.';
$_lang['perm.steal_locks_desc'] = 'To "steal" locks, overriding a current lock on a Resource.';
$_lang['perm.tree_show_resource_ids_desc'] = 'Show the IDs in the Resource tree.';
$_lang['perm.tree_show_element_ids_desc'] = 'Show the IDs in the Elements tree.';
$_lang['perm.undelete_desc'] = 'Basic permission to "undelete" any object.';
$_lang['perm.undelete_document_desc'] = 'To undelete any Resource.';
$_lang['perm.unlock_element_properties_desc'] = 'To be able to edit the default properties for any Element.';
$_lang['perm.unpublish_desc'] = 'To unpublish any Resource.';
$_lang['perm.unpublish_document_desc'] = 'To unpublish any Resources.';
$_lang['perm.usergroup_delete_desc'] = 'To delete a User Group.';
$_lang['perm.usergroup_edit_desc'] = 'To edit a User Group.';
$_lang['perm.usergroup_user_edit_desc'] = 'To edit Resources in a User Group.';
$_lang['perm.usergroup_user_list_desc'] = 'To view or list Users in a User Group.';
$_lang['perm.usergroup_new_desc'] = 'To create a new User Group.';
$_lang['perm.usergroup_save_desc'] = 'To save a User Group.';
$_lang['perm.usergroup_view_desc'] = 'To view a User Group.';
$_lang['perm.view_desc'] = 'Basic permission to "view" any object.';
$_lang['perm.view_category_desc'] = 'To view any Categories.';
$_lang['perm.view_chunk_desc'] = 'To view any Chunks.';
$_lang['perm.view_context_desc'] = 'To view any Contexts.';
$_lang['perm.view_document_desc'] = 'To view any Resources.';
$_lang['perm.view_element_desc'] = 'To get a list of Elements or Element classes.';
$_lang['perm.view_eventlog_desc'] = 'To view the Event Log.';
$_lang['perm.view_offline_desc'] = 'To be able to view the site when it is in offline status.';
$_lang['perm.view_plugin_desc'] = 'To view any Plugins.';
$_lang['perm.view_propertyset_desc'] = 'To view any Property Sets.';
$_lang['perm.view_role_desc'] = 'To view any Roles.';
$_lang['perm.view_snippet_desc'] = 'To view any Snippets.';
$_lang['perm.view_sysinfo_desc'] = 'To view the system info page.';
$_lang['perm.view_template_desc'] = 'To view any Templates.';
$_lang['perm.view_tv_desc'] = 'To view any Template Variables.';
$_lang['perm.view_unpublished_desc'] = 'To view any unpublished Resources.';
$_lang['perm.view_user_desc'] = 'To view any User.';
$_lang['perm.workspaces_desc'] = 'To use Package Management.';
